==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/ReasonCode.h <==
// public class gnu.java.security.x509.ext.ReasonCode

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 62e1e833f39f0cd0 gnu_java_security_x509_ext_ReasonCode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_ReasonCode_H_
#define _JC_gnu_java_security_x509_ext_ReasonCode_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_refs	_jc_gnu_java_security_x509_ext_ReasonCode$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs	_jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$refs	_jc_gnu_java_security_x509_ext_ReasonCode$refs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$nonrefs	_jc_gnu_java_security_x509_ext_ReasonCode$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$object	_jc_gnu_java_security_x509_ext_ReasonCode$object;

typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$fields_struct	_jc_gnu_java_security_x509_ext_ReasonCode$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_ReasonCode$vmethods	_jc_gnu_java_security_x509_ext_ReasonCode$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_ReasonCode$vtable	_jc_gnu_java_security_x509_ext_ReasonCode$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_ReasonCode$vtype	_jc_gnu_java_security_x509_ext_ReasonCode$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_ReasonCode$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24ReasonCode;
};
extern _jc_gnu_java_security_x509_ext_ReasonCode$fields_struct _jc_gnu_java_security_x509_ext_ReasonCode$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_ReasonCode$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *, struct _jc_byte_array *);

// Virtual methods
extern jint _jc_gnu_java_security_x509_ext_ReasonCode$method$getReasonCode$c6d45054644ba5a5(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_ReasonCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_ReasonCode$method_info$getReasonCode$c6d45054644ba5a5;
extern _jc_method _jc_gnu_java_security_x509_ext_ReasonCode$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_ReasonCode$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_ReasonCode$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_ReasonCode$vmethods {
	jint	(*getReasonCode$c6d45054644ba5a5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_ReasonCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_ReasonCode$vmethods	gnu_java_security_x509_ext_ReasonCode;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_ReasonCode$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_ReasonCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ReasonCode$refs {
    _jc_gnu_java_security_x509_ext_ReasonCode$sub_refs	gnu_java_security_x509_ext_ReasonCode;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs {
	jint	reason;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ReasonCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs	gnu_java_security_x509_ext_ReasonCode;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_ReasonCode$object {
	_jc_gnu_java_security_x509_ext_ReasonCode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_ReasonCode$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_ReasonCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_ReasonCode$vtype _jc_gnu_java_security_x509_ext_ReasonCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_ReasonCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_ReasonCode$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_ReasonCode_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/ReasonCode.h <==
// public class gnu.java.security.x509.ext.ReasonCode

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 62e1e833f39f0cd0 gnu_java_security_x509_ext_ReasonCode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_ReasonCode_H_
#define _JC_gnu_java_security_x509_ext_ReasonCode_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_refs	_jc_gnu_java_security_x509_ext_ReasonCode$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs	_jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$refs	_jc_gnu_java_security_x509_ext_ReasonCode$refs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$nonrefs	_jc_gnu_java_security_x509_ext_ReasonCode$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$object	_jc_gnu_java_security_x509_ext_ReasonCode$object;

typedef struct _jc_gnu_java_security_x509_ext_ReasonCode$fields_struct	_jc_gnu_java_security_x509_ext_ReasonCode$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_ReasonCode$vmethods	_jc_gnu_java_security_x509_ext_ReasonCode$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_ReasonCode$vtable	_jc_gnu_java_security_x509_ext_ReasonCode$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_ReasonCode$vtype	_jc_gnu_java_security_x509_ext_ReasonCode$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_ReasonCode$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24ReasonCode;
};
extern _jc_gnu_java_security_x509_ext_ReasonCode$fields_struct _jc_gnu_java_security_x509_ext_ReasonCode$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_ReasonCode$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_security_x509_ext_ReasonCode$method$getReasonCode$c6d45054644ba5a5(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_ReasonCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_ReasonCode$method_info$getReasonCode$c6d45054644ba5a5;
extern _jc_method _jc_gnu_java_security_x509_ext_ReasonCode$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_ReasonCode$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_ReasonCode$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_ReasonCode$vmethods {
	jint	(*getReasonCode$c6d45054644ba5a5)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ReasonCode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_ReasonCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_ReasonCode$vmethods	gnu_java_security_x509_ext_ReasonCode;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_ReasonCode$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_ReasonCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ReasonCode$refs {
    _jc_gnu_java_security_x509_ext_ReasonCode$sub_refs	gnu_java_security_x509_ext_ReasonCode;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs {
	jint	reason;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ReasonCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_ReasonCode$sub_nonrefs	gnu_java_security_x509_ext_ReasonCode;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_ReasonCode$object {
	_jc_gnu_java_security_x509_ext_ReasonCode$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_ReasonCode$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_ReasonCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_ReasonCode$vtype _jc_gnu_java_security_x509_ext_ReasonCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_ReasonCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_ReasonCode$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_ReasonCode_H_ */
